/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "JavaScriptCallFrame.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomJavaScriptCallFrame.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomJavaScriptCallFrame.h"
#include "gdom/PrivateIntGdomJavaScriptCallFrame.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::JavaScriptCallFrame* obj)
{
    return WebCore::cacheDOMObject<WebCore::JavaScriptCallFrame, GDOMJavaScriptCallFrame>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMJavaScriptCallFrame::GDOMJavaScriptCallFrame(PassRefPtr<WebCore::JavaScriptCallFrame> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMJavaScriptCallFrame::~GDOMJavaScriptCallFrame()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}


/* XXX TODO: custom function gdom_java_script_call_frame_evaluate */

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "JavaScriptCallFrame.h"
#include <gdom/GdomJavaScriptCallFrame.h>
#include <gdom/PrivateGdomJavaScriptCallFrame.h>
#include <gdom/PrivateIntGdomJavaScriptCallFrame.h>
#include <gdom/GdomJavaScriptCallFrameprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomJavaScriptCallFrame, gdom_java_script_call_frame, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomJavaScriptCallFramePrivate {
    class WebCore::JavaScriptCallFrame *item;
};

#define GDOM_JAVA_SCRIPT_CALL_FRAME_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_JAVA_SCRIPT_CALL_FRAME, GdomJavaScriptCallFramePrivate))
*/
G_END_DECLS
WebCore::JavaScriptCallFrame *
gdom_java_script_call_frame_get_private(GdomJavaScriptCallFrame *request)
{
    GDOMJavaScriptCallFrame *res;
    res = static_cast<GDOMJavaScriptCallFrame*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::JavaScriptCallFrame*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_CALLER,
    PROP_SOURCE_IDENTIFIER,
    PROP_LINE,
    PROP_FUNCTION_NAME,
};


static void gdom_java_script_call_frame_finalize(GObject* object)
{
    /*GdomJavaScriptCallFrame* request = GDOM_JAVA_SCRIPT_CALL_FRAME(object);*/
    /*GdomJavaScriptCallFramePrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_java_script_call_frame_parent_class)->finalize(object);
}

static void gdom_java_script_call_frame__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomJavaScriptCallFrame *self = GDOM_JAVA_SCRIPT_CALL_FRAME(object);
    WebCore::JavaScriptCallFrame * gself = (gdom_java_script_call_frame_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_java_script_call_frame__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomJavaScriptCallFrame *self = GDOM_JAVA_SCRIPT_CALL_FRAME(object);
    WebCore::JavaScriptCallFrame * gself = (gdom_java_script_call_frame_get_private(self));
    switch (prop_id) {
    case PROP_CALLER:
    {
         PassRefPtr<WebCore::JavaScriptCallFrame> ptr = gself->caller();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    case PROP_SOURCE_IDENTIFIER:
    {
         g_value_set_long (value, gself->sourceIdentifier());
         break;
    }
    case PROP_LINE:
    {
         g_value_set_long (value, gself->line());
         break;
    }
    case PROP_FUNCTION_NAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->functionName()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_java_script_call_frame_class_init(GdomJavaScriptCallFrameClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_java_script_call_frame_finalize;
    g_klass->set_property = gdom_java_script_call_frame__set_property_fn;
    g_klass->get_property = gdom_java_script_call_frame__get_property_fn;

    g_object_class_install_property (g_klass, PROP_CALLER,
            g_param_spec_object ("caller", /* name */
                "java_script_call_frame_caller", /* short description */
                "read-only  GdomJavaScriptCallFrame * JavaScriptCallFrame.caller", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_JAVA_SCRIPT_CALL_FRAME, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_SOURCE_IDENTIFIER,
            g_param_spec_long ("source_identifier", /* name */
                "java_script_call_frame_source_identifier", /* short description */
                "read-only  glong JavaScriptCallFrame.source_identifier", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_LINE,
            g_param_spec_long ("line", /* name */
                "java_script_call_frame_line", /* short description */
                "read-only  glong JavaScriptCallFrame.line", /* longer - could do with some extra doc stuff here */
                 G_MINLONG,        /* min */
                G_MAXLONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_FUNCTION_NAME,
            g_param_spec_string ("function_name", /* name */
                "java_script_call_frame_function_name", /* short description */
                "read-only  gchar * JavaScriptCallFrame.function_name", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomJavaScriptCallFramePrivate));*/
}

static void gdom_java_script_call_frame_init(GdomJavaScriptCallFrame* request)
{
    /*GdomJavaScriptCallFramePrivate* priv = GDOM_JAVA_SCRIPT_CALL_FRAME_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

